==> apache-calcite-1.12.0-src.tar.gz: apache-calcite-1.12.0-src/pig/src/main/java/org/apache/calcite/adapter/pig/PigTableFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.adapter.pig;

import org.apache.calcite.model.ModelHandler;
import org.apache.calcite.rel.type.RelDataType;
import org.apache.calcite.schema.SchemaPlus;
import org.apache.calcite.schema.TableFactory;

import java.io.File;
import java.util.List;
import java.util.Map;

/**
 * Factory that creates a {@link PigTable}.
 *
 * <p>Allows a Pig table to be included in a model.json file.</p>
 */
public class PigTableFactory implements TableFactory<PigTable> {
  // public constructor, per factory contract
  public PigTableFactory() {
  }

  @SuppressWarnings("unchecked")
  public PigTable create(SchemaPlus schema, String name,
      Map<String, Object> operand, RelDataType rowType) {
    String fileName = (String) operand.get("file");
    File file = new File(fileName);
    final File base =
        (File) operand.get(ModelHandler.ExtraOperand.BASE_DIRECTORY.camelName);
    if (base != null && !file.isAbsolute()) {
      file = new File(base, fileName);
    }
    final List<String> fieldNames = (List<String>) operand.get("columns");
    final PigTable result = new PigTable(file.getAbsolutePath(), fieldNames.toArray(new String[0]));
    schema.unwrap(PigSchema.class).registerTable(name, result);
    return result;
  }
}

// End PigTableFactory.java

==> apache-calcite-1.28.0-src.tar.gz: apache-calcite-1.28.0-src/pig/src/main/java/org/apache/calcite/adapter/pig/PigTableFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.adapter.pig;

import org.apache.calcite.model.ModelHandler;
import org.apache.calcite.rel.type.RelDataType;
import org.apache.calcite.schema.SchemaPlus;
import org.apache.calcite.schema.TableFactory;

import org.checkerframework.checker.nullness.qual.Nullable;

import java.io.File;
import java.util.List;
import java.util.Map;

/**
 * Factory that creates a {@link PigTable}.
 *
 * <p>Allows a Pig table to be included in a model.json file.</p>
 */
public class PigTableFactory implements TableFactory<PigTable> {
  // public constructor, per factory contract
  public PigTableFactory() {
  }

  @SuppressWarnings("unchecked")
  @Override public PigTable create(SchemaPlus schema, String name,
      Map<String, Object> operand, @Nullable RelDataType rowType) {
    String fileName = (String) operand.get("file");
    File file = new File(fileName);
    final File base =
        (File) operand.get(ModelHandler.ExtraOperand.BASE_DIRECTORY.camelName);
    if (base != null && !file.isAbsolute()) {
      file = new File(base, fileName);
    }
    final List<String> fieldNames = (List<String>) operand.get("columns");
    final PigTable result = new PigTable(file.getAbsolutePath(), fieldNames.toArray(new String[0]));
    schema.unwrap(PigSchema.class).registerTable(name, result);
    return result;
  }
}
